[java-opensaml] branch main updated: Add additional method override to default expiration.

Scott Cantor cantor.2 at osu.edu
Fri Aug 5 16:29:11 UTC 2022


This is an automated email from the git hooks/post-receive script.

scantor pushed a commit to branch main
in repository java-opensaml.

View the commit online:
http://git.shibboleth.net/view/?p=java-opensaml.git;a=commit;h=dbaaa85492e4bc36de2ad998beaaf5b858b4f796

The following commit(s) were added to refs/heads/main by this push:
     new dbaaa8549 Add additional method override to default expiration.
dbaaa8549 is described below

commit dbaaa85492e4bc36de2ad998beaaf5b858b4f796
Author: Scott Cantor <cantor.2 at osu.edu>
AuthorDate: Fri Aug 5 12:27:40 2022 -0400

    Add additional method override to default expiration.
---
 .../java/org/opensaml/storage/RevocationCache.java | 43 ++++++++++++++++------
 1 file changed, 32 insertions(+), 11 deletions(-)

diff --git a/opensaml-storage-api/src/main/java/org/opensaml/storage/RevocationCache.java b/opensaml-storage-api/src/main/java/org/opensaml/storage/RevocationCache.java
index 12d55d225..c8846cbca 100644
--- a/opensaml-storage-api/src/main/java/org/opensaml/storage/RevocationCache.java
+++ b/opensaml-storage-api/src/main/java/org/opensaml/storage/RevocationCache.java
@@ -140,26 +140,47 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * Invokes {@link #revoke(String, String, Duration)} with a default expiration parameter.
      * 
      * @param context a context label to subdivide the cache
      * @param s value to revoke
      * 
      * @return true if value has successfully been listed as revoked in the cache.
      */
-    public synchronized boolean revoke(@Nonnull @NotEmpty final String context, @Nonnull @NotEmpty final String s) {
-        return revoke(context, s, expires);
+    public synchronized boolean revoke(@Nonnull @NotEmpty final String context, @Nonnull @NotEmpty final String key) {
+        return revoke(context, key, expires);
     }    
 
     /**
-     * Returns true if the value is successfully revoked. If value has already been revoked, expiration is updated.
+     * Invokes {@link #revoke(String, String, String, Duration)} with a placeholder value parameter.
      * 
      * @param context a context label to subdivide the cache
      * @param s value to revoke
      * @param exp entry expiration
      * 
      * @return true if value has successfully been listed as revoked in the cache
      */
-    public synchronized boolean revoke(@Nonnull @NotEmpty final String context, @Nonnull @NotEmpty final String s,
+    public synchronized boolean revoke(@Nonnull @NotEmpty final String context, @Nonnull @NotEmpty final String key,
             @Nonnull final Duration exp) {
-        return revoke(context, s, "y", exp);
+        return revoke(context, key, "y", exp);
+    }
+
+    
+    /**
+     * Invokes {@link #revoke(String, String, String, Duration)} with a default expiration parameter.
+     * 
+     * <p>If the key has already been revoked, expiration is updated.</p>
+     * 
+     * @param context a context label to subdivide the cache
+     * @param key key to revoke
+     * @param value value to insert into revocation record
+     * 
+     * @return true if key has successfully been listed as revoked in the cache
+     * 
+     * @since 4.3.0
+     */
+    public synchronized boolean revoke(@Nonnull @NotEmpty final String context, @Nonnull @NotEmpty final String key,
+            @Nonnull @NotEmpty final String value) {
+        return revoke(context, key, value, expires);
     }
     
     /**
@@ -168,11 +189,11 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * <p>If the key has already been revoked, expiration is updated.</p>
      * 
      * @param context a context label to subdivide the cache
      * @param s value to revoke
      * @param value value to insert into revocation record
      * @param exp entry expiration
      * 
      * @return true if value has successfully been listed as revoked in the cache
      * 
      * @since 4.3.0
      */
@@ -140,26 +140,47 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * 
      * @param context a context label to subdivide the cache
-     * @param s value to revoke
+     * @param key key to revoke
      * 
@@ -140,26 +140,47 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * 
-     * @return true if value has successfully been listed as revoked in the cache.
+     * @return true if key has successfully been listed as revoked in the cache
      */
@@ -140,26 +140,47 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * 
      * @param context a context label to subdivide the cache
-     * @param s value to revoke
+     * @param key key to revoke
      * @param exp entry expiration
      * 
@@ -140,26 +140,47 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * @param exp entry expiration
      * 
-     * @return true if value has successfully been listed as revoked in the cache
+     * @return true if key has successfully been listed as revoked in the cache
+     * 
+     * @since 4.3.0
      */
@@ -168,11 +189,11 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * 
      * @param context a context label to subdivide the cache
-     * @param s value to revoke
+     * @param s key to revoke
      * @param value value to insert into revocation record
      * @param exp entry expiration
@@ -168,11 +189,11 @@ public class RevocationCache extends AbstractIdentifiableInitializableComponent
      * @param exp entry expiration
      * 
-     * @return true if value has successfully been listed as revoked in the cache
+     * @return true if key has successfully been listed as revoked in the cache
      * 
      * @since 4.3.0

-- 
To stop receiving notification emails like this one, please contact
the administrator of this repository.


More information about the commits mailing list